==> thunderbird-debug-147.0-1-x86_64.pkg.tar.zst: usr/src/debug/thunderbird/thunderbird-147.0/obj-x86_64-pc-linux-gnu/dom/bindings/WebIDLPrefs.cpp <==
#include "mozilla/StaticPrefs_accessibility.h"
#include "mozilla/StaticPrefs_beacon.h"
#include "mozilla/StaticPrefs_device.h"
#include "mozilla/StaticPrefs_dom.h"
#include "mozilla/StaticPrefs_extensions.h"
#include "mozilla/StaticPrefs_geo.h"
#include "mozilla/StaticPrefs_layout.h"
#include "mozilla/StaticPrefs_mathml.h"
#include "mozilla/StaticPrefs_media.h"
#include "mozilla/StaticPrefs_network.h"
#include "mozilla/StaticPrefs_privacy.h"
#include "mozilla/StaticPrefs_security.h"
#include "mozilla/StaticPrefs_svg.h"
#include "mozilla/StaticPrefs_webgl.h"
#include "mozilla/dom/WebIDLPrefs.h"

namespace mozilla::dom {
const WebIDLPrefFunc sWebIDLPrefs[] = {
  nullptr,
  // accessibility.ARIAElementReflection.enabled
  StaticPrefs::accessibility_ARIAElementReflection_enabled,
  // beacon.enabled
  StaticPrefs::beacon_enabled,
  // device.sensors.ambientLight.enabled
  StaticPrefs::device_sensors_ambientLight_enabled,
  // device.sensors.proximity.enabled
  StaticPrefs::device_sensors_proximity_enabled,
  // dom.battery.enabled
  StaticPrefs::dom_battery_enabled,
  // dom.capture.enabled
  StaticPrefs::dom_capture_enabled,
  // dom.cookieStore.enabled
  StaticPrefs::dom_cookieStore_enabled,
  // dom.cookieStore.manager.enabled
  StaticPrefs::dom_cookieStore_manager_enabled,
  // dom.customHighlightAPI.enabled
  StaticPrefs::dom_customHighlightAPI_enabled,
  // dom.details_group.enabled
  StaticPrefs::dom_details_group_enabled,
  // dom.dialog.light-dismiss.enabled
  StaticPrefs::dom_dialog_light_dismiss_enabled,
  // dom.element.blocking.enabled
  StaticPrefs::dom_element_blocking_enabled,
  // dom.element.commandfor.enabled
  StaticPrefs::dom_element_commandfor_enabled,
  // dom.element.dialog.request_close.enabled
  StaticPrefs::dom_element_dialog_request_close_enabled,
  // dom.enable_event_timing
  StaticPrefs::dom_enable_event_timing,
  // dom.enable_memory_stats
  StaticPrefs::dom_enable_memory_stats,
  // dom.enable_web_task_scheduling
  StaticPrefs::dom_enable_web_task_scheduling,
  // dom.event.pointer.rawupdate.enabled
  StaticPrefs::dom_event_pointer_rawupdate_enabled,
  // dom.fetchKeepalive.enabled
  StaticPrefs::dom_fetchKeepalive_enabled,
  // dom.forms.autocorrect
  StaticPrefs::dom_forms_autocorrect,
  // dom.fs.enabled
  StaticPrefs::dom_fs_enabled,
  // dom.gamepad.enabled
  StaticPrefs::dom_gamepad_enabled,
  // dom.gamepad.extensions.enabled
  StaticPrefs::dom_gamepad_extensions_enabled,
  // dom.gamepad.extensions.lightindicator
  StaticPrefs::dom_gamepad_extensions_lightindicator,
  // dom.gamepad.extensions.multitouch
  StaticPrefs::dom_gamepad_extensions_multitouch,
  // dom.gamepad.test.enabled
  StaticPrefs::dom_gamepad_test_enabled,
  // dom.hidden_until_found.enabled
  StaticPrefs::dom_hidden_until_found_enabled,
  // dom.indexedDB.experimental
  StaticPrefs::dom_indexedDB_experimental,
  // dom.intersection_observer.scroll_margin.enabled
  StaticPrefs::dom_intersection_observer_scroll_margin_enabled,
  // dom.media.autoplay-policy-detection.enabled
  StaticPrefs::dom_media_autoplay_policy_detection_enabled,
  // dom.mouse_capture.enabled
  StaticPrefs::dom_mouse_capture_enabled,
  // dom.movebefore.enabled
  StaticPrefs::dom_movebefore_enabled,
  // dom.netinfo.enabled
  StaticPrefs::dom_netinfo_enabled,
  // dom.origin_agent_cluster.enabled
  StaticPrefs::dom_origin_agent_cluster_enabled,
  // dom.performance.event_timing.enable_interactionid
  StaticPrefs::dom_performance_event_timing_enable_interactionid,
  // dom.performance.time_to_contentful_paint.enabled
  StaticPrefs::dom_performance_time_to_contentful_paint_enabled,
  // dom.performance.time_to_first_interactive.enabled
  StaticPrefs::dom_performance_time_to_first_interactive_enabled,
  // dom.performance.time_to_non_blank_paint.enabled
  StaticPrefs::dom_performance_time_to_non_blank_paint_enabled,
  // dom.pointer-lock.enabled
  StaticPrefs::dom_pointer_lock_enabled,
  // dom.push.enabled
  StaticPrefs::dom_push_enabled,
  // dom.screenwakelock.enabled
  StaticPrefs::dom_screenwakelock_enabled,
  // dom.security.featurePolicy.webidl.enabled
  StaticPrefs::dom_security_featurePolicy_webidl_enabled,
  // dom.security.sanitizer.enabled
  StaticPrefs::dom_security_sanitizer_enabled,
  // dom.security.trusted_types.enabled
  StaticPrefs::dom_security_trusted_types_enabled,
  // dom.select.showPicker.enabled
  StaticPrefs::dom_select_showPicker_enabled,
  // dom.serviceWorkers.navigationPreload.enabled
  StaticPrefs::dom_serviceWorkers_navigationPreload_enabled,
  // dom.shadowdom.referenceTarget.enabled
  StaticPrefs::dom_shadowdom_referenceTarget_enabled,
  // dom.shadowdom.selection_across_boundary_enabled
  StaticPrefs::dom_shadowdom_selection_across_boundary_enabled,
  // dom.storage.testing
  StaticPrefs::dom_storage_testing,
  // dom.storage_access.enabled
  StaticPrefs::dom_storage_access_enabled,
  // dom.storage_access.forward_declared.enabled
  StaticPrefs::dom_storage_access_forward_declared_enabled,
  // dom.testing.selection.GetRangesForInterval
  StaticPrefs::dom_testing_selection_GetRangesForInterval,
  // dom.textMetrics.actualBoundingBox.enabled
  StaticPrefs::dom_textMetrics_actualBoundingBox_enabled,
  // dom.textMetrics.baselines.enabled
  StaticPrefs::dom_textMetrics_baselines_enabled,
  // dom.textMetrics.emHeight.enabled
  StaticPrefs::dom_textMetrics_emHeight_enabled,
  // dom.textMetrics.fontBoundingBox.enabled
  StaticPrefs::dom_textMetrics_fontBoundingBox_enabled,
  // dom.text_fragments.enabled
  StaticPrefs::dom_text_fragments_enabled,
  // dom.vibrator.enabled
  StaticPrefs::dom_vibrator_enabled,
  // dom.viewTransitions.enabled
  StaticPrefs::dom_viewTransitions_enabled,
  // dom.vr.enabled
  StaticPrefs::dom_vr_enabled,
  // dom.vr.puppet.enabled
  StaticPrefs::dom_vr_puppet_enabled,
  // dom.vr.webxr.enabled
  StaticPrefs::dom_vr_webxr_enabled,
  // dom.webidl.test1
  StaticPrefs::dom_webidl_test1,
  // dom.webidl.test2
  StaticPrefs::dom_webidl_test2,
  // dom.webkitBlink.dirPicker.enabled
  StaticPrefs::dom_webkitBlink_dirPicker_enabled,
  // dom.webkitBlink.filesystem.enabled
  StaticPrefs::dom_webkitBlink_filesystem_enabled,
  // dom.webnotifications.actions.enabled
  StaticPrefs::dom_webnotifications_actions_enabled,
  // dom.webnotifications.requireinteraction.enabled
  StaticPrefs::dom_webnotifications_requireinteraction_enabled,
  // dom.webnotifications.silent.enabled
  StaticPrefs::dom_webnotifications_silent_enabled,
  // dom.webnotifications.vibrate.enabled
  StaticPrefs::dom_webnotifications_vibrate_enabled,
  // extensions.InstallTrigger.enabled
  StaticPrefs::extensions_InstallTrigger_enabled,
  // extensions.webidl-api.expose_mock_interface
  StaticPrefs::extensions_webidl_api_expose_mock_interface,
  // geo.enabled
  StaticPrefs::geo_enabled,
  // layout.accessiblecaret.magnifier.enabled
  StaticPrefs::layout_accessiblecaret_magnifier_enabled,
  // layout.css.anchor-positioning.enabled
  StaticPrefs::layout_css_anchor_positioning_enabled,
  // layout.css.anchor-positioning.position-try-order.enabled
  StaticPrefs::layout_css_anchor_positioning_position_try_order_enabled,
  // layout.css.convertFromNode.enabled
  StaticPrefs::layout_css_convertFromNode_enabled,
  // layout.css.field-sizing.enabled
  StaticPrefs::layout_css_field_sizing_enabled,
  // layout.css.font-palette.enabled
  StaticPrefs::layout_css_font_palette_enabled,
  // layout.css.font-variant-emoji.enabled
  StaticPrefs::layout_css_font_variant_emoji_enabled,
  // layout.css.font-variations.enabled
  StaticPrefs::layout_css_font_variations_enabled,
  // layout.css.grid-template-masonry-value.enabled
  StaticPrefs::layout_css_grid_template_masonry_value_enabled,
  // layout.css.initial-letter.enabled
  StaticPrefs::layout_css_initial_letter_enabled,
  // layout.css.moz-appearance.webidl.enabled
  StaticPrefs::layout_css_moz_appearance_webidl_enabled,
  // layout.css.moz-control-character-visibility.enabled
  StaticPrefs::layout_css_moz_control_character_visibility_enabled,
  // layout.css.osx-font-smoothing.enabled
  StaticPrefs::layout_css_osx_font_smoothing_enabled,
  // layout.css.prefixes.animations
  StaticPrefs::layout_css_prefixes_animations,
  // layout.css.prefixes.border-image
  StaticPrefs::layout_css_prefixes_border_image,
  // layout.css.prefixes.box-sizing
  StaticPrefs::layout_css_prefixes_box_sizing,
  // layout.css.prefixes.font-features
  StaticPrefs::layout_css_prefixes_font_features,
  // layout.css.prefixes.transforms
  StaticPrefs::layout_css_prefixes_transforms,
  // layout.css.prefixes.transitions
  StaticPrefs::layout_css_prefixes_transitions,
  // layout.css.properties-and-values.enabled
  StaticPrefs::layout_css_properties_and_values_enabled,
  // layout.css.scroll-anchoring.enabled
  StaticPrefs::layout_css_scroll_anchoring_enabled,
  // layout.css.scroll-driven-animations.enabled
  StaticPrefs::layout_css_scroll_driven_animations_enabled,
  // layout.css.text-autospace.enabled
  StaticPrefs::layout_css_text_autospace_enabled,
  // layout.css.text-decoration-inset.enabled
  StaticPrefs::layout_css_text_decoration_inset_enabled,
  // layout.css.typed-om.enabled
  StaticPrefs::layout_css_typed_om_enabled,
  // layout.css.zoom.enabled
  StaticPrefs::layout_css_zoom_enabled,
  // mathml.math_shift.enabled
  StaticPrefs::mathml_math_shift_enabled,
  // media.allowed-to-play.enabled
  StaticPrefs::media_allowed_to_play_enabled,
  // media.eme.hdcp-policy-check.enabled
  StaticPrefs::media_eme_hdcp_policy_check_enabled,
  // media.getdisplaymedia.enabled
  StaticPrefs::media_getdisplaymedia_enabled,
  // media.mediasource.enabled
  StaticPrefs::media_mediasource_enabled,
  // media.mediasource.experimental.enabled
  StaticPrefs::media_mediasource_experimental_enabled,
  // media.peerconnection.scripttransform.enabled
  StaticPrefs::media_peerconnection_scripttransform_enabled,
  // media.rvfc.enabled
  StaticPrefs::media_rvfc_enabled,
  // media.seekToNextFrame.enabled
  StaticPrefs::media_seekToNextFrame_enabled,
  // media.setsinkid.enabled
  StaticPrefs::media_setsinkid_enabled,
  // media.test.video-suspend
  StaticPrefs::media_test_video_suspend,
  // media.track.enabled
  StaticPrefs::media_track_enabled,
  // media.useAudioChannelService.testing
  StaticPrefs::media_useAudioChannelService_testing,
  // media.webspeech.synth.enabled
  StaticPrefs::media_webspeech_synth_enabled,
  // network.fetchpriority.enabled
  StaticPrefs::network_fetchpriority_enabled,
  // privacy.fingerprintingProtection.testing
  StaticPrefs::privacy_fingerprintingProtection_testing,
  // privacy.globalprivacycontrol.functionality.enabled
  StaticPrefs::privacy_globalprivacycontrol_functionality_enabled,
  // security.webauth.webauthn
  StaticPrefs::security_webauth_webauthn,
  // security.webauthn.enable_json_serialization_methods
  StaticPrefs::security_webauthn_enable_json_serialization_methods,
  // svg.SVGAElement.text.enabled
  StaticPrefs::svg_SVGAElement_text_enabled,
  // svg.context-properties.content.enabled
  StaticPrefs::svg_context_properties_content_enabled,
  // webgl.drawing_buffer_color_space
  StaticPrefs::webgl_drawing_buffer_color_space
};
} // namespace mozilla::dom

==> thunderbird-debug-148.0-1-x86_64.pkg.tar.zst: usr/src/debug/thunderbird/thunderbird-148.0/obj-x86_64-pc-linux-gnu/dom/bindings/WebIDLPrefs.cpp <==
#include "mozilla/StaticPrefs_accessibility.h"
#include "mozilla/StaticPrefs_beacon.h"
#include "mozilla/StaticPrefs_device.h"
#include "mozilla/StaticPrefs_dom.h"
#include "mozilla/StaticPrefs_extensions.h"
#include "mozilla/StaticPrefs_geo.h"
#include "mozilla/StaticPrefs_layout.h"
#include "mozilla/StaticPrefs_mathml.h"
#include "mozilla/StaticPrefs_media.h"
#include "mozilla/StaticPrefs_network.h"
#include "mozilla/StaticPrefs_privacy.h"
#include "mozilla/StaticPrefs_security.h"
#include "mozilla/StaticPrefs_svg.h"
#include "mozilla/StaticPrefs_webgl.h"
#include "mozilla/dom/WebIDLPrefs.h"

namespace mozilla::dom {
const WebIDLPrefFunc sWebIDLPrefs[] = {
  nullptr,
  // accessibility.ARIAElementReflection.enabled
  StaticPrefs::accessibility_ARIAElementReflection_enabled,
  // beacon.enabled
  StaticPrefs::beacon_enabled,
  // device.sensors.ambientLight.enabled
  StaticPrefs::device_sensors_ambientLight_enabled,
  // device.sensors.proximity.enabled
  StaticPrefs::device_sensors_proximity_enabled,
  // dom.battery.enabled
  StaticPrefs::dom_battery_enabled,
  // dom.capture.enabled
  StaticPrefs::dom_capture_enabled,
  // dom.cookieStore.enabled
  StaticPrefs::dom_cookieStore_enabled,
  // dom.customHighlightAPI.enabled
  StaticPrefs::dom_customHighlightAPI_enabled,
  // dom.details_group.enabled
  StaticPrefs::dom_details_group_enabled,
  // dom.dialog.light-dismiss.enabled
  StaticPrefs::dom_dialog_light_dismiss_enabled,
  // dom.documentpip.enabled
  StaticPrefs::dom_documentpip_enabled,
  // dom.element.blocking.enabled
  StaticPrefs::dom_element_blocking_enabled,
  // dom.element.commandfor.enabled
  StaticPrefs::dom_element_commandfor_enabled,
  // dom.element.dialog.request_close.enabled
  StaticPrefs::dom_element_dialog_request_close_enabled,
  // dom.enable_event_timing
  StaticPrefs::dom_enable_event_timing,
  // dom.enable_memory_stats
  StaticPrefs::dom_enable_memory_stats,
  // dom.enable_web_task_scheduling
  StaticPrefs::dom_enable_web_task_scheduling,
  // dom.event.pointer.rawupdate.enabled
  StaticPrefs::dom_event_pointer_rawupdate_enabled,
  // dom.fetchKeepalive.enabled
  StaticPrefs::dom_fetchKeepalive_enabled,
  // dom.forms.autocorrect
  StaticPrefs::dom_forms_autocorrect,
  // dom.fs.enabled
  StaticPrefs::dom_fs_enabled,
  // dom.gamepad.enabled
  StaticPrefs::dom_gamepad_enabled,
  // dom.gamepad.extensions.enabled
  StaticPrefs::dom_gamepad_extensions_enabled,
  // dom.gamepad.extensions.lightindicator
  StaticPrefs::dom_gamepad_extensions_lightindicator,
  // dom.gamepad.extensions.multitouch
  StaticPrefs::dom_gamepad_extensions_multitouch,
  // dom.gamepad.test.enabled
  StaticPrefs::dom_gamepad_test_enabled,
  // dom.hidden_until_found.enabled
  StaticPrefs::dom_hidden_until_found_enabled,
  // dom.indexedDB.experimental
  StaticPrefs::dom_indexedDB_experimental,
  // dom.intersection_observer.scroll_margin.enabled
  StaticPrefs::dom_intersection_observer_scroll_margin_enabled,
  // dom.location.ancestorOrigins.enabled
  StaticPrefs::dom_location_ancestorOrigins_enabled,
  // dom.media.autoplay-policy-detection.enabled
  StaticPrefs::dom_media_autoplay_policy_detection_enabled,
  // dom.mouse_capture.enabled
  StaticPrefs::dom_mouse_capture_enabled,
  // dom.movebefore.enabled
  StaticPrefs::dom_movebefore_enabled,
  // dom.netinfo.enabled
  StaticPrefs::dom_netinfo_enabled,
  // dom.origin_agent_cluster.enabled
  StaticPrefs::dom_origin_agent_cluster_enabled,
  // dom.performance.event_timing.enable_interactionid
  StaticPrefs::dom_performance_event_timing_enable_interactionid,
  // dom.performance.time_to_contentful_paint.enabled
  StaticPrefs::dom_performance_time_to_contentful_paint_enabled,
  // dom.performance.time_to_first_interactive.enabled
  StaticPrefs::dom_performance_time_to_first_interactive_enabled,
  // dom.performance.time_to_non_blank_paint.enabled
  StaticPrefs::dom_performance_time_to_non_blank_paint_enabled,
  // dom.pointer-lock.enabled
  StaticPrefs::dom_pointer_lock_enabled,
  // dom.push.enabled
  StaticPrefs::dom_push_enabled,
  // dom.screenwakelock.enabled
  StaticPrefs::dom_screenwakelock_enabled,
  // dom.security.featurePolicy.webidl.enabled
  StaticPrefs::dom_security_featurePolicy_webidl_enabled,
  // dom.security.sanitizer.enabled
  StaticPrefs::dom_security_sanitizer_enabled,
  // dom.security.trusted_types.enabled
  StaticPrefs::dom_security_trusted_types_enabled,
  // dom.select.showPicker.enabled
  StaticPrefs::dom_select_showPicker_enabled,
  // dom.serviceWorkers.navigationPreload.enabled
  StaticPrefs::dom_serviceWorkers_navigationPreload_enabled,
  // dom.shadowdom.referenceTarget.enabled
  StaticPrefs::dom_shadowdom_referenceTarget_enabled,
  // dom.shadowdom.selection_across_boundary_enabled
  StaticPrefs::dom_shadowdom_selection_across_boundary_enabled,
  // dom.storage.testing
  StaticPrefs::dom_storage_testing,
  // dom.storage_access.enabled
  StaticPrefs::dom_storage_access_enabled,
  // dom.storage_access.forward_declared.enabled
  StaticPrefs::dom_storage_access_forward_declared_enabled,
  // dom.testing.selection.GetRangesForInterval
  StaticPrefs::dom_testing_selection_GetRangesForInterval,
  // dom.textMetrics.actualBoundingBox.enabled
  StaticPrefs::dom_textMetrics_actualBoundingBox_enabled,
  // dom.textMetrics.baselines.enabled
  StaticPrefs::dom_textMetrics_baselines_enabled,
  // dom.textMetrics.emHeight.enabled
  StaticPrefs::dom_textMetrics_emHeight_enabled,
  // dom.textMetrics.fontBoundingBox.enabled
  StaticPrefs::dom_textMetrics_fontBoundingBox_enabled,
  // dom.text_fragments.enabled
  StaticPrefs::dom_text_fragments_enabled,
  // dom.vibrator.enabled
  StaticPrefs::dom_vibrator_enabled,
  // dom.viewTransitions.enabled
  StaticPrefs::dom_viewTransitions_enabled,
  // dom.vr.enabled
  StaticPrefs::dom_vr_enabled,
  // dom.vr.puppet.enabled
  StaticPrefs::dom_vr_puppet_enabled,
  // dom.vr.webxr.enabled
  StaticPrefs::dom_vr_webxr_enabled,
  // dom.webidl.test1
  StaticPrefs::dom_webidl_test1,
  // dom.webidl.test2
  StaticPrefs::dom_webidl_test2,
  // dom.webkitBlink.dirPicker.enabled
  StaticPrefs::dom_webkitBlink_dirPicker_enabled,
  // dom.webkitBlink.filesystem.enabled
  StaticPrefs::dom_webkitBlink_filesystem_enabled,
  // dom.webnotifications.actions.enabled
  StaticPrefs::dom_webnotifications_actions_enabled,
  // dom.webnotifications.requireinteraction.enabled
  StaticPrefs::dom_webnotifications_requireinteraction_enabled,
  // dom.webnotifications.silent.enabled
  StaticPrefs::dom_webnotifications_silent_enabled,
  // dom.webnotifications.vibrate.enabled
  StaticPrefs::dom_webnotifications_vibrate_enabled,
  // extensions.InstallTrigger.enabled
  StaticPrefs::extensions_InstallTrigger_enabled,
  // extensions.webidl-api.expose_mock_interface
  StaticPrefs::extensions_webidl_api_expose_mock_interface,
  // geo.enabled
  StaticPrefs::geo_enabled,
  // layout.accessiblecaret.magnifier.enabled
  StaticPrefs::layout_accessiblecaret_magnifier_enabled,
  // layout.css.anchor-positioning.enabled
  StaticPrefs::layout_css_anchor_positioning_enabled,
  // layout.css.anchor-positioning.position-try-order.enabled
  StaticPrefs::layout_css_anchor_positioning_position_try_order_enabled,
  // layout.css.convertFromNode.enabled
  StaticPrefs::layout_css_convertFromNode_enabled,
  // layout.css.field-sizing.enabled
  StaticPrefs::layout_css_field_sizing_enabled,
  // layout.css.font-palette.enabled
  StaticPrefs::layout_css_font_palette_enabled,
  // layout.css.font-variant-emoji.enabled
  StaticPrefs::layout_css_font_variant_emoji_enabled,
  // layout.css.font-variations.enabled
  StaticPrefs::layout_css_font_variations_enabled,
  // layout.css.grid-template-masonry-value.enabled
  StaticPrefs::layout_css_grid_template_masonry_value_enabled,
  // layout.css.initial-letter.enabled
  StaticPrefs::layout_css_initial_letter_enabled,
  // layout.css.moz-appearance.webidl.enabled
  StaticPrefs::layout_css_moz_appearance_webidl_enabled,
  // layout.css.moz-control-character-visibility.enabled
  StaticPrefs::layout_css_moz_control_character_visibility_enabled,
  // layout.css.osx-font-smoothing.enabled
  StaticPrefs::layout_css_osx_font_smoothing_enabled,
  // layout.css.prefixes.animations
  StaticPrefs::layout_css_prefixes_animations,
  // layout.css.prefixes.border-image
  StaticPrefs::layout_css_prefixes_border_image,
  // layout.css.prefixes.box-sizing
  StaticPrefs::layout_css_prefixes_box_sizing,
  // layout.css.prefixes.font-features
  StaticPrefs::layout_css_prefixes_font_features,
  // layout.css.prefixes.transforms
  StaticPrefs::layout_css_prefixes_transforms,
  // layout.css.prefixes.transitions
  StaticPrefs::layout_css_prefixes_transitions,
  // layout.css.properties-and-values.enabled
  StaticPrefs::layout_css_properties_and_values_enabled,
  // layout.css.scroll-anchoring.enabled
  StaticPrefs::layout_css_scroll_anchoring_enabled,
  // layout.css.scroll-driven-animations.enabled
  StaticPrefs::layout_css_scroll_driven_animations_enabled,
  // layout.css.text-autospace.enabled
  StaticPrefs::layout_css_text_autospace_enabled,
  // layout.css.text-decoration-inset.enabled
  StaticPrefs::layout_css_text_decoration_inset_enabled,
  // layout.css.typed-om.enabled
  StaticPrefs::layout_css_typed_om_enabled,
  // layout.css.zoom.enabled
  StaticPrefs::layout_css_zoom_enabled,
  // mathml.math_shift.enabled
  StaticPrefs::mathml_math_shift_enabled,
  // media.allowed-to-play.enabled
  StaticPrefs::media_allowed_to_play_enabled,
  // media.eme.hdcp-policy-check.enabled
  StaticPrefs::media_eme_hdcp_policy_check_enabled,
  // media.getdisplaymedia.enabled
  StaticPrefs::media_getdisplaymedia_enabled,
  // media.mediasource.enabled
  StaticPrefs::media_mediasource_enabled,
  // media.mediasource.experimental.enabled
  StaticPrefs::media_mediasource_experimental_enabled,
  // media.peerconnection.scripttransform.enabled
  StaticPrefs::media_peerconnection_scripttransform_enabled,
  // media.rvfc.enabled
  StaticPrefs::media_rvfc_enabled,
  // media.seekToNextFrame.enabled
  StaticPrefs::media_seekToNextFrame_enabled,
  // media.setsinkid.enabled
  StaticPrefs::media_setsinkid_enabled,
  // media.test.video-suspend
  StaticPrefs::media_test_video_suspend,
  // media.track.enabled
  StaticPrefs::media_track_enabled,
  // media.useAudioChannelService.testing
  StaticPrefs::media_useAudioChannelService_testing,
  // media.webspeech.synth.enabled
  StaticPrefs::media_webspeech_synth_enabled,
  // network.fetchpriority.enabled
  StaticPrefs::network_fetchpriority_enabled,
  // privacy.fingerprintingProtection.testing
  StaticPrefs::privacy_fingerprintingProtection_testing,
  // privacy.globalprivacycontrol.functionality.enabled
  StaticPrefs::privacy_globalprivacycontrol_functionality_enabled,
  // security.webauth.webauthn
  StaticPrefs::security_webauth_webauthn,
  // security.webauthn.enable_json_serialization_methods
  StaticPrefs::security_webauthn_enable_json_serialization_methods,
  // svg.SVGAElement.text.enabled
  StaticPrefs::svg_SVGAElement_text_enabled,
  // svg.context-properties.content.enabled
  StaticPrefs::svg_context_properties_content_enabled,
  // webgl.drawing_buffer_color_space
  StaticPrefs::webgl_drawing_buffer_color_space
};
} // namespace mozilla::dom
